@@ -2,7 +2,7 @@
  *
  * XASTIR, Amateur Station Tracking and Information Reporting
  * Copyright (C) 1999,2000  Frank Giannandrea
- * Copyright (C) 2000-2018 The Xastir Group
+ * Copyright (C) 2000-2019 The Xastir Group
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -38,6 +38,9 @@ extern int gps_data_find(char *gps_line_data, int port);
 
 extern void create_garmin_waypoint(long latitude,long longitude,char *call_sign);
 
+int isGGA(char *gps_line_data);
+int isRMC(char *gps_line_data);
+
 #endif  // __XASTIR_GPS_H
 
 
