@@ -2,7 +2,7 @@
  *
  * XASTIR, Amateur Station Tracking and Information Reporting
  * Copyright (C) 1999,2000  Frank Giannandrea
- * Copyright (C) 2000-2018 The Xastir Group
+ * Copyright (C) 2000-2019 The Xastir Group
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -32,7 +32,7 @@ typedef struct
   char name[10];
   Widget popup_message_dialog;
   Widget popup_message_data;
-  Widget pane, form, button_close;
+  Widget pane, scrollwindow, form, button_close;
   time_t sec_opened;
 
 } Popup_Window;
