@@ -34,6 +34,20 @@
 #define XTPOINTER_TO_INT(m_p)  ((int)((long)(m_p)))
 
 
+// Defines we can use to mark functions and parameters as "unused" to the compiler
+#ifdef __GNUC__
+  #define UNUSED(x) UNUSED_ ## x __attribute__((__unused__))
+#else
+  #define UNUSED(x) UNUSED_ ## x
+#endif
+
+#ifdef __GNUC__
+  #define UNUSED_FUNCTION(x) __attribute__((__unused__)) UNUSED_ ## x
+#else
+  #define UNUSED_FUNCTION(x) UNUSED_ ## x
+#endif
+
+
 #define SERIAL_KISS_RELAY_DIGI
 
 
@@ -69,7 +83,7 @@
 #define CONVERT_HP_NORMAL_FORMATED       9
 
 #ifndef M_PI                      /* if not defined in math.h */
-#define M_PI 3.14159265358979323846
+  #define M_PI 3.14159265358979323846
 #endif  // M_PI
 
 #define SPEECH_TEST_STRING      "Greeteengz frum eggzaster"
@@ -104,7 +118,8 @@ extern void create_gc(Widget w);
 extern void Station_info(Widget w, XtPointer clientData, XtPointer calldata);
 
 extern void fix_dialog_size(Widget w);
-extern void fix_dialog_vsize(Widget w);
+
+void resize_dialog( Widget form, Widget dialog);
 
 extern int debug_level;
 extern GC gc;
@@ -165,8 +180,8 @@ extern int index_maps_on_startup;
 extern char rotated_label_fontname[FONT_MAX][MAX_LABEL_FONTNAME];
 
 #ifdef HAVE_LIBGEOTIFF
-extern int DRG_XOR_colors;
-extern int DRG_show_colors[13];
+  extern int DRG_XOR_colors;
+  extern int DRG_show_colors[13];
 #endif  // HAVE_LIBGEOTIFF
 
 
@@ -241,7 +256,7 @@ extern void popup_ID_message(char *banner, char *message);
 
 /* from view_messages.c */
 extern void all_messages(char from, char *call_sign, char *from_call, char *message);
-extern void view_all_messages(Widget w, XtPointer clientData, XtPointer callData);   
+extern void view_all_messages(Widget w, XtPointer clientData, XtPointer callData);
 
 /* from db.c */
 extern void setup_in_view(void);
